.. _Glossary:

Glossary
========

.. glossary::

   MVM
        margin value method

   MAN
      margin analysis network

   DOE
      design of experiments

   CDF
      cumulative density function

   CAC
      change absorption capability

   IoP
      impact on performance

   MVP
      margin value map

   DV
      decided value

   TT
      target threshold

   DSE
      design space exploration

   API
      design space exploration